@@ -35,16 +35,16 @@ rand_bytes() {
 	cmds='date; date +%N; free; who -a; w; ps auxww; ps ef; netstat -n'
 	data=$( (eval "$cmds") 2>&1 | gzip )
 
-	n_plus_50=$(expr $n + 50)
+	n_plus_50=$(( n + 50 ))
 
 	# Ensure that $data has length at least 50+$n
 	while :; do
 		len=$(echo "$data" | wc -c)
-		test $n_plus_50 -le $len && break;
+		test "$n_plus_50" -le "$len" && break;
 		data=$( (echo "$data"; eval "$cmds") 2>&1 | gzip )
 	done
 
-	echo "$data" | dd bs=1 skip=50 count=$n 2>/dev/null \
+	echo "$data" | dd bs=1 skip=50 count="$n" 2>/dev/null \
 		| tr -c "$chars" "01234567$chars$chars$chars"
 }
 
@@ -97,7 +97,7 @@ mkdtemp() {
 		err=$(mkdir -m 0700 "$candidate_dir" 2>&1) && \
 			{ echo "$candidate_dir"; return; }
 		test $MAX_TRIES -le $i && break;
-		i=$(expr $i + 1)
+		i=$(( i + 1 ))
 	done
 	die "$err"
 }
@@ -109,48 +109,61 @@ grep1_() {
 
 stacktrace() {
 	trap - ERR
-	local i=0
+	# i=1 - ignoring innermost frame - it is always stacktrace function
+	local i=1 n=${#BASH_LINENO[*]}
+	# n-=1 - ignoring last frame as well - it is not interesting
+	let n-=1
 
-	echo "## - $0:${BASH_LINENO[0]}"
-	while FUNC=${FUNCNAME[$i]}; test "$FUNC" != "main"; do
-		echo "## $i ${FUNC}() called from ${BASH_SOURCE[$i]}:${BASH_LINENO[$i]}"
-		i=$(($i + 1))
+	echo "## - $0:${BASH_LINENO[$((n-1))]}"
+	while [[ $i -lt $n ]]; do
+		echo "## $i ${FUNCNAME[$i]}() called from ${BASH_SOURCE[$((i+1))]}:${BASH_LINENO[$i]}"
+		i=$(( i + 1 ))
 	done
 }
 
 STACKTRACE() {
 	trap - ERR
-	local i=0
+	local i
 
 	stacktrace
 
-	test "${LVM_TEST_PARALLEL:-0}" -eq 1 -o -n "$RUNNING_DMEVENTD" -o -f LOCAL_DMEVENTD || {
-		pgrep dmeventd &>/dev/null && \
-			die "ERROR: The test started dmeventd unexpectedly."
-	}
+	test "${LVM_TEST_PARALLEL:-0}" -eq 0 && test -z "$RUNNING_DMEVENTD" && \
+		test ! -f LOCAL_DMEVENTD && pgrep dmeventd >DPID 2>/dev/null  && {
+			echo "## ERROR: The test started dmeventd ($(< DPID)) unexpectedly."
+			kill "$(< DPID)"
+		}
 
 	# Get backtraces from coredumps
 	if which gdb &>/dev/null; then
-		echo bt full > gdb_commands.txt
-		echo l >> gdb_commands.txt
-		echo quit >> gdb_commands.txt
-		for core in $(ls core* 2>/dev/null); do
-			bin=$(gdb -batch -c "$core" 2>&1 | grep "generated by" | \
-			sed -e "s,.*generated by \`\([^ ']*\).*,\1,")
-			gdb -batch -c "$core" -x gdb_commands.txt $(which "$bin")
-		done
+		{
+			echo bt full
+			echo l
+			echo quit
+		} > gdb_commands.txt
+
+		# Check for all cores newer then TESTNAME file
+		# Assume users keep prefix 'core'
+		# TODO: possibly better integrate with coredumpctl & systemd
+		while IFS= read -r i; do
+			bin=$(gdb -batch -c "$i" 2>&1 | grep "generated by" | \
+			sed -e "s,.*generated by \`\([^ ']*\).*,\1,") || continue
+			echo "## Checking coredump: $i generated by $bin."
+			gdb -batch -c "$i" -x gdb_commands.txt "$(which "$bin")" 2>/dev/null | \
+			sed -e "s,^,## GDB:	," || continue
+		done < <(find . "$(dirname "$(sysctl -n kernel.core_pattern)")" \
+			"/var/lib/systemd/coredump/" -name 'core*' -newer TESTNAME 2>/dev/null || true)
 	fi
 
 	test -f SKIP_THIS_TEST && exit 200
 
-	test -z "$LVM_TEST_NODEBUG" -a -f TESTNAME && {
+	test -z "$LVM_TEST_NODEBUG" && test -f TESTNAME && {
 		local name
-		local idx
+		local idx=0
 		for i in debug.log* ; do
 			test -f "$i" || break  # nothing is found (expands to debug.log*)
 			name=${i##debug.log_}
 			name=${name%%_*}
-			test "$name" = "DEBUG" && { name="$name$idx" ; idx=$(($idx + 1)) ; }
+			test "$name" = "DEBUG" && { name="$name$idx" ; idx=$(( idx + 1 )) ; }
 			echo "<======== Debug log $i ========>"
 			sed -e "s,^,## $name: ," "$i"
 		done
@@ -159,7 +172,7 @@ STACKTRACE() {
 			sed -e "s,^,## STRACE: ," strace.log
 		fi
 		dmsetup info -c | grep1_ "$PREFIX" > out
-		if test $(wc -l < out) -gt 1 ; then
+		if test "$(wc -l < out)" -gt 1 ; then
 			echo "<======== Info ========>"
 			sed -e "s,^,## DMINFO:   ," out
 			echo "<======== Active table ========>"
@@ -188,14 +201,15 @@ STACKTRACE() {
 
 init_udev_transaction() {
 	if test "$DM_UDEV_SYNCHRONISATION" = 1; then
-		local cookie=$(dmsetup udevcreatecookie)
+		local cookie
+		cookie=$(dmsetup udevcreatecookie)
 		# Cookie is not generated if udev is not running!
 		test -z "$cookie" || export DM_UDEV_COOKIE=$cookie
 	fi
 }
 
 finish_udev_transaction() {
-	if test "$DM_UDEV_SYNCHRONISATION" = 1 -a -n "$DM_UDEV_COOKIE"; then
+	if test "$DM_UDEV_SYNCHRONISATION" = 1 && test -n "$DM_UDEV_COOKIE" ; then
 		dmsetup udevreleasecookie
 		unset DM_UDEV_COOKIE
 	fi
@@ -223,7 +237,7 @@ skip() {
 	if test "$#" -eq 0; then
 		stacktrace
 	else
-		echo "TEST SKIPPED: $@"
+		echo "TEST SKIPPED:" "$@"
 	fi
 	touch SKIP_THIS_TEST
 	exit 200
@@ -241,12 +255,10 @@ prepare_test_vars() {
 	vg="${PREFIX}vg"
 	lv=LV
 
-	for i in $(seq 1 16); do
-		name="${PREFIX}pv$i"
-		dev="$DM_DEV_DIR/mapper/$name"
-		eval "dev$i=\"$dev\""
-		eval "lv$i=LV$i"
-		eval "vg$i=${PREFIX}vg$i"
+	for i in {1..16}; do
+		eval "dev$i=\"$DM_DEV_DIR/mapper/${PREFIX}pv$i\""
+		eval "lv$i=\"LV$i\""
+		eval "vg$i=\"${PREFIX}vg$i\""
 	done
 }
 
@@ -258,7 +270,7 @@ if test -z "${installed_testsuite+varset}"; then
     case "$PATH" in
     *"$abs_top_builddir/test/lib"*) ;;
     *)
-	PATH="$abs_top_builddir/test/lib":"$abs_top_builddir/test/api":$PATH
+	PATH="$abs_top_builddir/test/lib:$abs_top_builddir/test/api:$PATH"
 	LD_LIBRARY_PATH=$(find -L "$abs_top_builddir/libdm/" "$abs_top_builddir/tools/"\
 		"$abs_top_builddir/daemons/" "$abs_top_builddir/liblvm/"\
 		-name "*.so" -printf "%h:")"$LD_LIBRARY_PATH"
