@@ -1,4 +1,5 @@
-#!/bin/sh
+#!/usr/bin/env bash
+
 # Copyright (C) 2008 Red Hat, Inc. All rights reserved.
 #
 # This copyrighted material is made available to anyone wishing to use,
@@ -24,7 +25,7 @@ aux prepare_vg 5
 #COMM "test various read ahead settings (bz450922)"
 lvcreate -l 100%FREE -i5 -I512 -n $lv $vg
 ra=$(get lv_field $vg/$lv lv_kernel_read_ahead --units s --nosuffix)
-test $(( ( $ra / 5 ) * 5 )) -le $ra
+test $(( ( ra / 5 ) * 5 )) -le $ra
 not lvchange -r auto $vg/$lv 2>&1 | grep auto
 check lv_field $vg/$lv lv_read_ahead auto
 lvchange -r 640 $vg/$lv
@@ -35,7 +36,7 @@ lvremove -ff $vg
 blockdev --setra 768 "$dev1"
 vgscan
 lvcreate -n $lv -L4m $vg "$dev1"
-test $(blockdev --getra "$DM_DEV_DIR/$vg/$lv") -eq 768
+test "$(blockdev --getra "$DM_DEV_DIR/$vg/$lv")" -eq 768
 lvremove -ff $vg
 
 # Check default, active/inactive values for read_ahead / kernel_read_ahead
